BuiltValueNestedFieldError class

Error indicating that a built_value build method failed because a nested field builder failed.

Inheritance

Constructors

BuiltValueNestedFieldError(String type, String field, String error)

Properties

error → String
final
field → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited