StringJsonObject class

A JsonObject holding a String.

Inheritance

Constructors

StringJsonObject(String value)

Properties

asBool → bool
The value as a bool, or throw if not.
no setterinherited
asList → List
The value as a List, or throw if not.
no setterinherited
asMap → Map
The value as a Map, or throw if not.
no setterinherited
asNum → num
The value as a num, or throw if not.
no setterinherited
asString → String
The value as a String, or throw if not.
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isBool → bool
Whether the value is a bool.
no setterinherited
isList → bool
Whether the value is a List.
no setterinherited
isMap → bool
Whether the value is a Map.
no setterinherited
isNum → bool
Whether the value is a num.
no setterinherited
isString → bool
Whether the value is a String.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The value, which may be a bool, a List, a Map, a num or a String.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override